colour.algebra.coordinates — Colour 0.3.0 documentation

# Source code for colour.algebra.coordinates

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .transformations import cartesian_to_spherical, spherical_to_cartesian
    from .transformations import cartesian_to_cylindrical, cylindrical_to_cartesian

    __all__ = ['cartesian_to_spherical',
               'spherical_to_cartesian',
               'cartesian_to_cylindrical',
               'cylindrical_to_cartesian']